@@ -11,6 +11,7 @@ use crossterm::{
     style::Stylize,
     terminal, Command, ExecutableCommand,
 };
+use notify_rust::Notification;
 
 use crate::utils::{backspace, get_formatted_time, input, print, println};
 
@@ -25,6 +26,12 @@ impl User {
         let name = loop {
             let mut name = input("Enter your name: ");
             name = name.trim().to_string();
+
+            if name.contains(";") {
+                println!("Name cannot contain ';'");
+                continue;
+            }
+
             if name.len() > 0 {
                 break name;
             }
@@ -39,7 +46,7 @@ impl User {
     }
 
     fn send(&self, msg: &str) {
-        let msg = format!("{}: {}\n", self.name.clone().red(), msg);
+        let msg = format!("{};{}\n", self.name, msg);
         let mut stream = self.stream.try_clone().unwrap();
 
         stream.write(msg.as_bytes()).unwrap();
@@ -59,13 +66,17 @@ impl User {
                 break;
             }
 
-            match notify_rust::Notification::new().body(&msg).show() {
-                Ok(_) => (),
-                Err(err) => println(&err.to_string()),
-            }
+            let (name, msg) = msg.split_once(";").unwrap();
+            Notification::new()
+                .summary(name)
+                .body(msg)
+                .appname("Rust Chat")
+                .show()
+                .ok();
 
+            let name = name.red();
             let time = get_formatted_time().red();
-            print(&format!("\r[{}] {}", time, msg));
+            print(&format!("\r[{}] {}: {}", time, name, msg));
             self.print_current_msg();
         }
     }
@@ -110,14 +121,15 @@ impl User {
     }
 
     fn print_current_msg(&self) {
+        let name = self.name.as_str().green();
         let msg = self.current_msg.lock().unwrap();
-        let msg = format!("{}: {}", self.name.clone().green(), msg);
+        let msg = format!("{}: {}", name, msg);
         print(&msg);
     }
 
     fn print_current_complete_msg(&self) {
         let msg = self.current_msg.lock().unwrap();
-        let name = self.name.clone().green();
+        let name = self.name.as_str().green();
         let time = get_formatted_time().green();
 
         let msg = format!("[{}] {}: {}", time, name, msg);
